==> spirit_hub-0.1.1.30.tar.gz: spirit_hub-0.1.1.30/app/helpers/spirit_hub/user_display_option_helper.rb <==
# frozen_string_literal: true

module SpiritHub
  module UserDisplayOptionHelper
    DEFAULT_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      operation_title: { label: SpiritHub::Setting.main_object_name.capitalize, sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Dernière modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    DIRECTORIES_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Dernière modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      phase_title: { label: 'Phase', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    TO_CLASSIFY_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Dernière modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    OPERATIONS_COLUMNS = {
      code: { label: 'Code', sortable: true },
      title: { label: 'Libellé', sortable: true },
      city: { label: 'Ville', sortable: true },
      postal_code: { label: 'Code postal', sortable: true },
      status: { label: 'Statut', sortable: true },
      agency: { label: 'Agence', sortable: true },
      type: { label: 'Type', sortable: true }
    }.freeze

    TEAM_ACTIVITIES_COLUMNS = {
      first_name: { label: 'Nom', sortable: true },
      to_be_signed_docs: { label: 'À signer', sortable: true, icon: 'fa-file-signature' },
      to_be_signed_for_me_docs: { label: 'À signer pour moi', sortable: true, icon: 'fa-pen' },
      to_complete_docs: { label: 'À compléter', sortable: true, icon: 'fa-pen' },
      to_validate_docs: { label: 'À valider', sortable: true, icon: 'fa-circle-check' },
      responses_docs: { label: 'Réponses', sortable: true, icon: 'fa-share', color: 'blue' }
    }.freeze

    COLLABORATORS_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Dernière modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    CONTROLLER_COLUMNS = {
      'directories' => DIRECTORIES_COLUMNS,
      'operations' => OPERATIONS_COLUMNS,
      'team_activities/collaborator' => TEAM_ACTIVITIES_COLUMNS,
      'to_classify' => TO_CLASSIFY_COLUMNS,
      'collaborators' => COLLABORATORS_COLUMNS,
      'todos' => DEFAULT_COLUMNS,
      'shared' => DEFAULT_COLUMNS,
      'search' => DEFAULT_COLUMNS,
      'favorites' => DEFAULT_COLUMNS
    }.freeze

    def self.get_columns_for(user, controller_name)
      display_option = user.display_option.reload
      all_columns = CONTROLLER_COLUMNS.fetch(controller_name, DEFAULT_COLUMNS)
      hidden_columns = Array(display_option.hidden_columns&.dig(controller_name)).map(&:to_sym)

      visible_columns = all_columns.each_with_object({}) do |(key, value), hash|
        hash[key] = value unless hidden_columns.include?(key)
      end

      [all_columns, visible_columns.keys, visible_columns]
    end
  end
end

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/app/helpers/spirit_hub/user_display_option_helper.rb <==
# frozen_string_literal: true

module SpiritHub
  module UserDisplayOptionHelper
    DEFAULT_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      operation_title: { label: SpiritHub::Setting.main_object_name.capitalize, sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    DIRECTORIES_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      phase_title: { label: 'Phase', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    TO_CLASSIFY_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    OPERATIONS_COLUMNS = {
      code: { label: 'Code', sortable: true },
      title: { label: 'Libellé', sortable: true },
      city: { label: 'Ville', sortable: true },
      postal_code: { label: 'Code postal', sortable: true },
      status: { label: 'Statut', sortable: true },
      agency: { label: 'Agence', sortable: true },
      type: { label: 'Type', sortable: true }
    }.freeze

    TEAM_ACTIVITIES_COLUMNS = {
      first_name: { label: 'Nom', sortable: true },
      to_be_signed_docs: { label: 'À signer', sortable: true, icon: 'fa-file-signature' },
      to_be_signed_for_me_docs: { label: 'À signer pour moi', sortable: true, icon: 'fa-pen' },
      to_complete_docs: { label: 'À compléter', sortable: true, icon: 'fa-pen' },
      to_validate_docs: { label: 'À valider', sortable: true, icon: 'fa-circle-check' },
      responses_docs: { label: 'Réponses', sortable: true, icon: 'fa-share', color: 'blue' }
    }.freeze

    COLLABORATORS_COLUMNS = {
      type: { label: 'Type', sortable: true },
      cleaned_main_key: { label: 'Libellé', sortable: true },
      doc_file_size: { label: 'Poids', sortable: true },
      updated_at: { label: 'Modification', sortable: true },
      last_current_user_name: { label: 'Provenance', sortable: true },
      informed: { label: 'Partagé', sortable: false },
      current_state: { label: 'Statut', sortable: true }
    }.freeze

    CONTROLLER_COLUMNS = {
      'directories' => DIRECTORIES_COLUMNS,
      'operations' => OPERATIONS_COLUMNS,
      'team_activities/collaborator' => TEAM_ACTIVITIES_COLUMNS,
      'to_classify' => TO_CLASSIFY_COLUMNS,
      'collaborators' => COLLABORATORS_COLUMNS,
      'todos' => DEFAULT_COLUMNS,
      'shared' => DEFAULT_COLUMNS,
      'search' => DEFAULT_COLUMNS,
      'favorites' => DEFAULT_COLUMNS
    }.freeze

    def self.get_columns_for(user, controller_name)
      display_option = user.display_option.reload
      all_columns = CONTROLLER_COLUMNS.fetch(controller_name, DEFAULT_COLUMNS)
      hidden_columns = Array(display_option.hidden_columns&.dig(controller_name)).map(&:to_sym)

      visible_columns = all_columns.each_with_object({}) do |(key, value), hash|
        hash[key] = value unless hidden_columns.include?(key)
      end

      [all_columns, visible_columns.keys, visible_columns]
    end
  end
end
